## 一、目录说明
```
├── README.md               # 帮助文档
├── .gitignore              # 配置忽略
├── test_report             # 测试报告存放文件夹
├── logs                    # 执行日志存放文件夹
├── conf                    # 配置存放目录
│   ├── global.json
│   └── ...
└── testcases               # python测试用例存放目录
    ├── demo1.py
    └── ...
```